custom_multi_search library
A customizable multi-select dropdown widget with search functionality.
The custom_multi_search library provides a widget that allows
users to select multiple items from a dropdown with integrated
search support. It also includes state management through
DataSelectionStore.
Classes
-
DataSelectionStore<
T> -
A store that manages the selection state of items in
the
CustomMultiSearchwidget. -
DataSelectionWidget<
T> - SearchItem
- A simple model class for search items